==> deepin-image-viewer_1.2.19.orig.tar.gz: deepin-image-viewer-1.2.19/CHANGELOG.md <==
<a name="1.2.19"></a>
### 1.2.19 (2018-04-11)


#### Features

* **print_dialog:**  add image settings option. ([53a8c772](53a8c772))



<a name="1.2.18"></a>
### 1.2.18 (2018-03-22)


#### Features

*   set wallpaper with dbus in flatpak ([30b00248](30b00248))

#### Bug Fixes

*   favorite menu and title states not synced ([2b16ceaa](2b16ceaa))

<a name="1.2.17"></a>
## 1.2.17 (2018-03-15)


#### Features

*   add notice for tif ([60e5a2da](60e5a2da))
*   add manual id ([65408f0b](65408f0b))
*   imageutils cutSquareImage support hidpi ([67fcbbb7](67fcbbb7))

#### Bug Fixes

*   toast hide failed ([9955ccfb](9955ccfb))
*   cleared item can be shown again ([afbc2b45](afbc2b45))
*   remove stays-on-top hint from scan dialog ([7c559016](7c559016))
*   build failed on static build ([c917a434](c917a434))
*   set titlebar background transparent ([c9dc6da9](c9dc6da9))
*   set pixmap device pixel ratio to device pixel ratio of window ([c792a3d5](c792a3d5))
*   remove seek operation ([b2019875](b2019875))
*   dxcb workaround ([c9cc715a](c9cc715a))
*   Adapt lintian ([dcad7f8a](dcad7f8a))
*   hide image on press super+d ([ca79cd62](ca79cd62))
*   set wallpaper by dde dbus ([b6f9a64c](b6f9a64c))
*   mainwindow button now showing on dark mode ([af0ff636](af0ff636))
*   Replace dbus-send with QDBusInterface ([86599aa4](86599aa4))
*   skip de check for flatpak ([3655aa3c](3655aa3c))
*   fix install path ([efefd53e](efefd53e))
*   setting wallpaper(convert the image's format). ([646d32c7](646d32c7))
* **hidpi:**
  *  top-left mainwindow icon not scaled ([54c971f8](54c971f8))
  *  some widgets are not showing clear ([4ba95264](4ba95264))
  *  some parts are not shown very clear ([4910a8af](4910a8af))
* **slideshow:**  cursor not showing with menu ([bd1e3499](bd1e3499))
* **timeline:**
  *  menu content changed after showing ([6b306252](6b306252))
  *  timeline date not showing ([3116dd53](3116dd53))

==> deepin-image-viewer_1.2.23.orig.tar.gz: deepin-image-viewer-1.2.23/CHANGELOG.md <==
<a name="1.2.23"></a>
### 1.2.23 (2018-07-20)


#### Bug Fixes

*   memory leak ([d680e97c](https://github.com/linuxdeepin/deepin-image-viewer/commit/d680e97c63df617b34bdda0dd3aaa3d2bb347caa))



<a name="1.2.22"></a>
## 1.2.22 (2018-05-24)


#### Bug Fixes

*   don't restore cursor. ([6f81631e](6f81631e))
* **flatpak:**  default save path error in flatpak environment ([699b4ae6](699b4ae6))



<a name="1.2.21"></a>
## 1.2.21 (2018-05-15)

*   Fix image is empty


<a name="1.2.20"></a>
## 1.2.20 (2018-05-14)


#### Bug Fixes

*   can't print image in landscape mode ([a63841a3](a63841a3))



<a name="1.2.19"></a>
### 1.2.19 (2018-04-11)


#### Features

* **print_dialog:**  add image settings option. ([53a8c772](53a8c772))



<a name="1.2.18"></a>
### 1.2.18 (2018-03-22)


#### Features

*   set wallpaper with dbus in flatpak ([30b00248](30b00248))

#### Bug Fixes

*   favorite menu and title states not synced ([2b16ceaa](2b16ceaa))

<a name="1.2.17"></a>
## 1.2.17 (2018-03-15)


#### Features

*   add notice for tif ([60e5a2da](60e5a2da))
*   add manual id ([65408f0b](65408f0b))
*   imageutils cutSquareImage support hidpi ([67fcbbb7](67fcbbb7))

#### Bug Fixes

*   toast hide failed ([9955ccfb](9955ccfb))
*   cleared item can be shown again ([afbc2b45](afbc2b45))
*   remove stays-on-top hint from scan dialog ([7c559016](7c559016))
*   build failed on static build ([c917a434](c917a434))
*   set titlebar background transparent ([c9dc6da9](c9dc6da9))
*   set pixmap device pixel ratio to device pixel ratio of window ([c792a3d5](c792a3d5))
*   remove seek operation ([b2019875](b2019875))
*   dxcb workaround ([c9cc715a](c9cc715a))
*   Adapt lintian ([dcad7f8a](dcad7f8a))
*   hide image on press super+d ([ca79cd62](ca79cd62))
*   set wallpaper by dde dbus ([b6f9a64c](b6f9a64c))
*   mainwindow button now showing on dark mode ([af0ff636](af0ff636))
*   Replace dbus-send with QDBusInterface ([86599aa4](86599aa4))
*   skip de check for flatpak ([3655aa3c](3655aa3c))
*   fix install path ([efefd53e](efefd53e))
*   setting wallpaper(convert the image's format). ([646d32c7](646d32c7))
* **hidpi:**
  *  top-left mainwindow icon not scaled ([54c971f8](54c971f8))
  *  some widgets are not showing clear ([4ba95264](4ba95264))
  *  some parts are not shown very clear ([4910a8af](4910a8af))
* **slideshow:**  cursor not showing with menu ([bd1e3499](bd1e3499))
* **timeline:**
  *  menu content changed after showing ([6b306252](6b306252))
  *  timeline date not showing ([3116dd53](3116dd53))
